@@ -351,7 +351,7 @@ metaprop <- function(event, n, studlab,
               tau.common=tau.common,
               prediction=prediction,
               method.bias=method.bias,
-              title="", complab="", outclab="",
+              title=title, complab=complab, outclab=outclab,
               keepdata=keepdata,
               data=if (keepdata) data else NULL,
               subset=if (keepdata) subset else NULL,
